.. _experimental_api:

Experimental API
================

This page describes the new ESMValCore API.
The experimental API module is available in the submodule ``esmvalcore.experimental``.
The API is under development, so use at your own risk!

.. toctree::
   :maxdepth: 1

   esmvalcore.experimental.config
   esmvalcore.experimental.recipe
   esmvalcore.experimental.recipe_output
   esmvalcore.experimental.recipe_metadata
   esmvalcore.experimental.utils
